@@ -8,6 +8,8 @@
 
 using SigC::bind;
 using SigC::slot;
+using std::cout;
+using std::endl;
 
 class MyWin : public Gtk::Window
 {
@@ -63,3 +65,5 @@ int main(int argc, char *argv[])
   myapp.run();
   return 0;
 }
+
+
