@@ -28,8 +28,8 @@
 
 #line 3 "parser.yy"
 
-#include <cstdio>
-#include <cstdlib>
+#include <stdio.h>
+#include <stdlib.h>
 #include <iostream>
 #include <string>
 #include <list>
@@ -48,13 +48,12 @@ extern "C"
 {
 int yylex();
 int yyparse();
-char *getenv();
 }
 
 extern FILE *yyout, *yyin;
 
 
-#line 31 "parser.yy"
+#line 30 "parser.yy"
 typedef union {
   int ival;
   string* sval;
@@ -153,13 +152,13 @@ static const short yyrhs[] = {    35,
 
 #if YYDEBUG != 0
 static const short yyrline[] = { 0,
-    52,    53,    56,    57,    58,    59,    60,    61,    62,    88,
-   105,   125,   129,   138,   142,   146,   156,   160,   164,   170,
-   175,   180,   189,   198,   208,   216,   223,   230,   236,   238,
-   240,   247,   253,   257,   264,   268,   272,   284,   289,   297,
-   301,   305,   311,   312,   319,   330,   343,   361,   372,   377,
-   384,   389,   437,   446,   456,   468,   473,   477,   481,   485,
-   491,   495,   499
+    51,    52,    55,    56,    57,    58,    59,    60,    61,    87,
+   104,   124,   128,   137,   141,   145,   155,   159,   163,   169,
+   174,   179,   188,   197,   207,   215,   222,   229,   235,   237,
+   239,   246,   252,   256,   263,   267,   271,   283,   288,   296,
+   300,   304,   310,   311,   318,   329,   342,   360,   371,   376,
+   383,   388,   436,   445,   455,   467,   472,   476,   480,   484,
+   490,   494,   498
 };
 #endif
 
@@ -833,7 +832,7 @@ yyreduce:
   switch (yyn) {
 
 case 10:
-#line 89 "parser.yy"
+#line 88 "parser.yy"
 {
 #ifdef DEBUG
   cout << "WRAPCLASSDECL" << endl;
@@ -852,7 +851,7 @@ case 10:
 ;
     break;}
 case 11:
-#line 106 "parser.yy"
+#line 105 "parser.yy"
 {
 #ifdef DEBUG
   cout << "WRAPCLASSDECL" << endl;
@@ -872,13 +871,13 @@ case 11:
 ;
     break;}
 case 12:
-#line 126 "parser.yy"
+#line 125 "parser.yy"
 {
   yyval.sval = yyvsp[0].sval;
 ;
     break;}
 case 13:
-#line 130 "parser.yy"
+#line 129 "parser.yy"
 {
   *(yyvsp[-1].sval)+=" ";
   *(yyvsp[-1].sval)+=*(yyvsp[0].sval);
@@ -887,19 +886,19 @@ case 13:
 ;
     break;}
 case 14:
-#line 139 "parser.yy"
+#line 138 "parser.yy"
 {
   yyval.sval = new string("const");
 ;
     break;}
 case 15:
-#line 143 "parser.yy"
+#line 142 "parser.yy"
 {
   yyval.sval = new string("volatile");
 ;
     break;}
 case 16:
-#line 147 "parser.yy"
+#line 146 "parser.yy"
 {
 #ifdef GTKMM_FIXME_GTK_CONST
  yyval.sval = new string("const");
@@ -909,41 +908,41 @@ case 16:
 ;
     break;}
 case 17:
-#line 157 "parser.yy"
+#line 156 "parser.yy"
 {
   yyval.sval = yyvsp[0].sval;
 ;
     break;}
 case 18:
-#line 161 "parser.yy"
+#line 160 "parser.yy"
 {
   yyval.sval = yyvsp[0].sval;
 ;
     break;}
 case 19:
-#line 165 "parser.yy"
+#line 164 "parser.yy"
 {
   yyval.sval = yyvsp[0].sval;
 ;
     break;}
 case 20:
-#line 171 "parser.yy"
+#line 170 "parser.yy"
 {
   *(yyvsp[-1].sval)+="*";
   yyval.sval = yyvsp[-1].sval;
 ;
     break;}
 case 21:
-#line 176 "parser.yy"
+#line 175 "parser.yy"
 {
   *(yyvsp[-1].sval)+="&";
   yyval.sval = yyvsp[-1].sval;
 ;
     break;}
 case 22:
-#line 181 "parser.yy"
+#line 180 "parser.yy"
 {
-  if (*(yyvsp[0].sval) != "") {
+  if ((yyvsp[0].sval)->length ()) {
     *(yyvsp[-1].sval)+=" ";
   }
   *(yyvsp[-1].sval)+=*(yyvsp[0].sval);
@@ -952,9 +951,9 @@ case 22:
 ;
     break;}
 case 23:
-#line 190 "parser.yy"
+#line 189 "parser.yy"
 {
-  if (*(yyvsp[-1].sval) != "") {
+  if ((yyvsp[-1].sval)->length ()) {
     *(yyvsp[-1].sval)+=" ";
   }
   *(yyvsp[-1].sval)+=*(yyvsp[0].sval);
@@ -963,13 +962,13 @@ case 23:
 ;
     break;}
 case 24:
-#line 199 "parser.yy"
+#line 198 "parser.yy"
 {
   yyval.sval = yyvsp[0].sval;
 ;
     break;}
 case 25:
-#line 209 "parser.yy"
+#line 208 "parser.yy"
 {
   *(yyvsp[-3].sval)+="<";
   *(yyvsp[-3].sval)+=*(yyvsp[-1].sval);
@@ -979,14 +978,14 @@ case 25:
 ;
     break;}
 case 26:
-#line 217 "parser.yy"
+#line 216 "parser.yy"
 {
   *(yyvsp[-2].sval)+="<>";
   yyval.sval = yyvsp[-2].sval;
 ;
     break;}
 case 27:
-#line 224 "parser.yy"
+#line 223 "parser.yy"
 {
   *(yyvsp[-2].sval)+=",";
   *(yyvsp[-2].sval)+=*(yyvsp[0].sval);
@@ -995,25 +994,25 @@ case 27:
 ;
     break;}
 case 28:
-#line 231 "parser.yy"
+#line 230 "parser.yy"
 {
   yyval.sval = yyvsp[0].sval;
 ;
     break;}
 case 29:
-#line 237 "parser.yy"
+#line 236 "parser.yy"
 { yyval.sval=yyvsp[0].sval; ;
     break;}
 case 30:
-#line 239 "parser.yy"
+#line 238 "parser.yy"
 { yyval.sval=yyvsp[0].sval; ;
     break;}
 case 31:
-#line 241 "parser.yy"
+#line 240 "parser.yy"
 { yyval.sval=new string("|"); ;
     break;}
 case 32:
-#line 248 "parser.yy"
+#line 247 "parser.yy"
 { 
   *(yyvsp[-1].sval)+=*(yyvsp[0].sval);
   delete yyvsp[0].sval;
@@ -1021,46 +1020,46 @@ case 32:
 ;
     break;}
 case 33:
-#line 254 "parser.yy"
+#line 253 "parser.yy"
 {
   yyval.sval=yyvsp[0].sval;
 ;
     break;}
 case 34:
-#line 258 "parser.yy"
+#line 257 "parser.yy"
 {
   *(yyvsp[-1].sval)="("+*(yyvsp[-1].sval)+")";
   yyval.sval=yyvsp[-1].sval;
 ;
     break;}
 case 35:
-#line 265 "parser.yy"
+#line 264 "parser.yy"
 {
   yyval.vval = new Argument(yyvsp[0].sval);
 ;
     break;}
 case 36:
-#line 269 "parser.yy"
+#line 268 "parser.yy"
 {
   yyval.vval = new Argument(yyvsp[-1].sval,yyvsp[0].sval);
 ;
     break;}
 case 37:
-#line 273 "parser.yy"
+#line 272 "parser.yy"
 {
   yyval.vval = new Argument(yyvsp[-3].sval,yyvsp[-2].sval,yyvsp[0].sval);
 //  cout << "value = " << *($<sval>4) <<endl;
 ;
     break;}
 case 38:
-#line 285 "parser.yy"
+#line 284 "parser.yy"
 {
   (yyvsp[-2].aval)->push_arg(yyvsp[0].vval);
   yyval.aval = yyvsp[-2].aval;
 ;
     break;}
 case 39:
-#line 290 "parser.yy"
+#line 289 "parser.yy"
 {
   ArgList* l = new ArgList();
   l->push_arg(yyvsp[0].vval);
@@ -1068,32 +1067,32 @@ case 39:
 ;
     break;}
 case 40:
-#line 298 "parser.yy"
+#line 297 "parser.yy"
 {
   yyval.fval = new FunctionDef(yyvsp[-3].sval,yyvsp[-2].sval);
 ;
     break;}
 case 41:
-#line 302 "parser.yy"
+#line 301 "parser.yy"
 {
   yyval.fval = new FunctionDef(yyvsp[-4].sval,yyvsp[-3].sval,yyvsp[-1].aval);
 ;
     break;}
 case 42:
-#line 306 "parser.yy"
+#line 305 "parser.yy"
 {
   yyval.fval = new FunctionDef(yyvsp[-4].sval,yyvsp[-3].sval,yyvsp[-1].aval);
 ;
     break;}
 case 44:
-#line 313 "parser.yy"
+#line 312 "parser.yy"
 {
   (yyvsp[-1].fval)->mark_const();
   yyval.fval = yyvsp[-1].fval;
 ;
     break;}
 case 45:
-#line 320 "parser.yy"
+#line 319 "parser.yy"
 {
 #ifdef DEBUG
   cout<< "WRAP_METHOD 1:" 
@@ -1106,7 +1105,7 @@ case 45:
 ;
     break;}
 case 46:
-#line 331 "parser.yy"
+#line 330 "parser.yy"
 {
 #ifdef DEBUG
   cout<< "WRAP_STATIC_METHOD 1:" 
@@ -1119,7 +1118,7 @@ case 46:
 ;
     break;}
 case 47:
-#line 344 "parser.yy"
+#line 343 "parser.yy"
 {
 #ifdef DEBUG
   cout << "WRAP_MEMBER" 
@@ -1136,7 +1135,7 @@ case 47:
 ;
     break;}
 case 48:
-#line 362 "parser.yy"
+#line 361 "parser.yy"
 {
 #ifdef DEBUG
   cout << "ENDCLASS"<<endl;
@@ -1147,35 +1146,35 @@ case 48:
 ;
     break;}
 case 49:
-#line 373 "parser.yy"
+#line 372 "parser.yy"
 {
   yyval.ival=(yyvsp[-2].ival) | sig_attribute(yyvsp[0].sval);
   delete yyvsp[0].sval;
 ;
     break;}
 case 50:
-#line 378 "parser.yy"
+#line 377 "parser.yy"
 {
   yyval.ival= sig_attribute(yyvsp[0].sval);
   delete yyvsp[0].sval;
 ;
     break;}
 case 51:
-#line 385 "parser.yy"
+#line 384 "parser.yy"
 {
   yyval.ival=(yyvsp[-2].ival) | member_attribute(yyvsp[0].sval);
   delete yyvsp[0].sval;
 ;
     break;}
 case 52:
-#line 390 "parser.yy"
+#line 389 "parser.yy"
 {
   yyval.ival= member_attribute(yyvsp[0].sval);
   delete yyvsp[0].sval;
 ;
     break;}
 case 53:
-#line 438 "parser.yy"
+#line 437 "parser.yy"
 {
 #ifdef DEBUG
   cout << " SIGNALDECL (\""<< *(yyvsp[-6].sval) <<"\", "<< (yyvsp[-3].ival) <<","<< (yyvsp[-1].fval)->get_function() << ")" <<endl;
@@ -1186,7 +1185,7 @@ case 53:
 ;
     break;}
 case 54:
-#line 447 "parser.yy"
+#line 446 "parser.yy"
 {
   yyvsp[-5].ival|=ATTR_EMIT;
 #ifdef DEBUG
@@ -1198,7 +1197,7 @@ case 54:
 ;
     break;}
 case 55:
-#line 457 "parser.yy"
+#line 456 "parser.yy"
 {
   yyvsp[-5].ival|=ATTR_TRANSLATE|ATTR_EMIT;
 #ifdef DEBUG
@@ -1210,50 +1209,50 @@ case 55:
 ;
     break;}
 case 56:
-#line 469 "parser.yy"
+#line 468 "parser.yy"
 {
   channel->section_class(*(yyvsp[-1].sval)); 
   delete yyvsp[-1].sval;
 ;
     break;}
 case 57:
-#line 474 "parser.yy"
+#line 473 "parser.yy"
 {
   channel->section_class();
 ;
     break;}
 case 58:
-#line 478 "parser.yy"
+#line 477 "parser.yy"
 {
   channel->section_impl(); 
 ;
     break;}
 case 59:
-#line 482 "parser.yy"
+#line 481 "parser.yy"
 {
   channel->section_doc(); 
 ;
     break;}
 case 60:
-#line 486 "parser.yy"
+#line 485 "parser.yy"
 {
   channel->section_private(); 
 ;
     break;}
 case 61:
-#line 492 "parser.yy"
+#line 491 "parser.yy"
 {
   currentWidget->set_cast_ctor(yyout);
 ;
     break;}
 case 62:
-#line 496 "parser.yy"
+#line 495 "parser.yy"
 {
   currentWidget->set_default_ctor(yyout);
 ;
     break;}
 case 63:
-#line 500 "parser.yy"
+#line 499 "parser.yy"
 {
   currentWidget->set_dtor(yyout);
 ;
@@ -1480,7 +1479,7 @@ yyerrhandle:
     }
   return 1;
 }
-#line 506 "parser.yy"
+#line 505 "parser.yy"
 
 
 int sig_attribute(string *s)
